@@ -121,7 +121,7 @@ class CustomLanguage:
         """
         if not isinstance(your_text, str): raise TypeError("Must be str")
         elif your_text == "": raise ValueError("This Text cannot be empty!")
-        self._try_again = your_text + (" " if not your_text.endswith(" ") else "")
+        self._your_code = your_text + (" " if not your_text.endswith(" ") else "")
     
     @wrong_user.setter
     def wrong_user(self, your_text: str):
@@ -182,7 +182,7 @@ class CaptchaOptions:
         self._max_incorrect_to_auto_reload: int = max_incorrect_to_auto_reload
         self._add_noise: bool = add_noise
         self._only_digits: bool = only_digits
-        self._custom_language: CustomLanguage = custom_language
+        self.custom_language: CustomLanguage = custom_language
 
     @property
     def generator(self) -> str: return self._generator
@@ -317,11 +317,12 @@ class CaptchaOptions:
         You can setup your own language if yours is not implemented
         Default: None
         """
-        if not isinstance(value, CustomLanguage):
-            raise TypeError("must be a CustomLanguage type")
-        self._custom_language = value
-        self._language = "custom"
-        languages["custom"] = value.to_dict()
+        if value:
+            if not isinstance(value, CustomLanguage):
+                raise TypeError("must be a CustomLanguage type")
+            self._custom_language = value
+            self._language = "custom"
+            languages["custom"] = value.to_dict()
 
 
 class Captcha(types.JsonDeserializable, types.JsonSerializable):
